@@ -1,3 +1,4 @@
+import socket
 import time
 
 # import paho.mqtt.client as mqtt
@@ -14,20 +15,35 @@ class ResultHandlerMqtt:
 
     def __init__(self, access_token, mqtt_obj):
         host = mqtt_obj.get("host")
-
+        self.host = host
+        self.port = mqtt_obj.get("port")
         self.connected_devices = {}
-
+        self.connected = False
         self.client = mqttClient.Client()
         self.client.username_pw_set(access_token)
         # Connect to ThingsBoard using default MQTT port and 60 seconds keepalive interval
         try:
             self.client.connect(host, mqtt_obj.get("port"), 60)
             self.client.loop_start()
-        except:
+            self.connected = True
+        except socket.error:
             print("can not connect mqtt broker!")
+            port = mqtt_obj.get("port")
+            self.try_to_connect(host, port)
             # TODO - bağlanamasa belli aralıklara bağlanmayı tekrar denesin, bağlanamadığ sırada veri gelirse o veriyi hafızada belirli bir süre/miktar tutmalı.
             #  bağlantı oluşur oluşmaz bu biriken veriler de gönderilmelidir.
 
+    def try_to_connect(self, host, port):
+        try:
+            self.client.connect(host, port, 60)
+            self.client.loop_start()
+            self.connected = True
+        except socket.error:
+            import time
+            print("can not connect mqtt broker, trying again in 15 seconds")
+            time.sleep(15)
+            self.try_to_connect(self.host, self.port)
+
     def send_connect_request(self, device_name):
         mqtt_data = {"device": device_name}
         self.client.publish('v1/gateway/connect', json.dumps(mqtt_data), 1)
@@ -39,13 +55,16 @@ class ResultHandlerMqtt:
         self.connected_devices.pop(device_name)
 
     def save_result(self, results, device=None, runner_name=None, data_type='telemetry'):
-        if self.connected_devices.get(device) is None:
-            self.send_connect_request(device)
+        if self.connected is True:
+            if self.connected_devices.get(device) is None:
+                self.send_connect_request(device)
 
-        if data_type == 'telemetry':
-            self.send_telemetry(device, results)
-        elif data_type == 'attribute':
-            self.send_attribute(device, results)
+            if data_type == 'telemetry':
+                self.send_telemetry(device, results)
+            elif data_type == 'attribute':
+                self.send_attribute(device, results)
+        else:
+            self.try_to_connect(self.host, self.port)
 
     def send_telemetry(self, device, results):
         try:
@@ -71,6 +90,7 @@ class ResultHandlerMqtt:
                 mqtt_data[device].append(single_data)
             if not len(mqtt_data[device]) == 0:
                 self.client.publish('v1/gateway/telemetry', json.dumps(mqtt_data), 1)
+
         except KeyError:
             print('Exception while saving result, key error')
 
@@ -100,3 +120,4 @@ class ResultHandlerMqtt:
     def dispose(self):
         # TODO - disconnect devices
         pass
+
