@@ -17,7 +17,7 @@ from ndu_gate_camera.camera.result_handlers.result_handler_mqtt import ResultHan
 from ndu_gate_camera.utility import onnx_helper
 from ndu_gate_camera.utility.constants import DEFAULT_NDU_GATE_CONF, DEFAULT_NDU_GATE_CONF_WIN, DEFAULT_HANDLER_SETTINGS
 from ndu_gate_camera.utility.ndu_utility import NDUUtility
-
+import logging.config
 
 def _get_config():
     print(sys.argv)
@@ -80,13 +80,17 @@ def main(ndu_gate_config_file):
             import platform
             if platform.system() == "Darwin":
                 ndu_gate_config_dir + "logs_macosx.conf"
-            # logging.config.fileConfig(logging_config_file, disable_existing_loggers=False)
+
+            logging.config.fileConfig(logging_config_file, disable_existing_loggers=False)
         except Exception as e:
             print(e)
             NDULoggerHandler.set_default_handler()
 
         global log
         log = logging.getLogger('service')
+        #TEMP LOGGER
+        #os.chmod("C:\\Users\\emre\\Documents\\GitHub\\ndu-gate\\ndu_gate_camera\\logs\\example.log", 0o777)
+        #logging.basicConfig(filename='C:\\Users\\emre\\Documents\\GitHub\\ndu-gate\\ndu_gate_camera\\logs\\example.log')
         log.info("NDUCameraService starting...")
         log.info("NDU-Gate logging config file: %s", logging_config_file)
         log.info("NDU-Gate logging service level: %s", log.level)
